Shared-Space Plugin — CKEditor Sample

# CKEditor Samples » Sharing Toolbar and Bottom-bar Spaces

This sample is not maintained anymore. Check out its brand new version in CKEditor SDK.

This sample shows several editor instances that share the very same spaces for both the toolbar and the bottom bar.

### Integer condimentum sit amet

Aenean nonummy a, mattis varius. Cras aliquet. Praesent magna non mattis ac, rhoncus nunc, rhoncus eget, cursus pulvinar mollis.

Proin id nibh. Sed eu libero posuere sed, lectus. Phasellus dui gravida gravida feugiat mattis ac, felis.

Integer condimentum sit amet, tempor elit odio, a dolor non ante at sapien. Sed ac lectus. Nulla ligula quis eleifend mi, id leo velit pede cursus arcu id nulla ac lectus. Phasellus vestibulum. Nunc viverra enim quis diam.

### Praesent wisi accumsan sit amet nibh

Donec ullamcorper, risus tortor, pretium porttitor. Morbi quam quis lectus non leo.

Integer faucibus scelerisque. Proin faucibus at, aliquet vulputate, odio at eros. Fusce gravida, erat vitae augue. Fusce urna fringilla gravida.

In hac habitasse platea dictumst. Praesent wisi accumsan sit amet nibh. Maecenas orci luctus a, lacinia quam sem, posuere commodo, odio condimentum tempor, pede semper risus. Suspendisse pede. In hac habitasse platea dictumst. Nam sed laoreet sit amet erat. Integer.